@@ -13,6 +13,9 @@
 @interface NSString (SupportedMedia)
 
 - (BOOL)isSupportedMediaFormat;
+- (BOOL)isSupportedAudioMediaFormat;
 - (BOOL)isSupportedSubtitleFormat;
 
+- (BOOL)isSupportedFormat;
+
 @end
