@@ -9,8 +9,8 @@
 //
 
 #import <Foundation/Foundation.h>
-#import "VLCLinearProgressIndicator.h"
 
+@class VLCLinearProgressIndicator;
 @interface VLCPlaylistTableViewCell : UITableViewCell
 
 @property (nonatomic, strong) IBOutlet UILabel *titleLabel;
@@ -21,7 +21,7 @@
 @property (nonatomic, strong) IBOutlet UILabel *artistNameLabel;
 @property (nonatomic, strong) IBOutlet UILabel *albumNameLabel;
 
-@property (nonatomic, retain) NSManagedObject *mediaObject;
+@property (nonatomic, strong) NSManagedObject *mediaObject;
 
 + (VLCPlaylistTableViewCell *)cellWithReuseIdentifier:(NSString *)ident;
 + (CGFloat)heightOfCell;
